@@ -6,14 +6,14 @@
 use v5.8;
 
 package Parallel::WorkUnit;
-$Parallel::WorkUnit::VERSION = '1.008';
+$Parallel::WorkUnit::VERSION = '1.009';
 # ABSTRACT: Provide easy-to-use forking with ability to pass back data
 
 use strict;
 use warnings;
 use autodie;
 
-use TryCatch;
+use Try::Tiny;
 my $do_thread = eval 'use threads qw//; 1' if $^O eq 'MSWin32';
 if ($do_thread) { eval 'use Thread::Queue;'; }
 
@@ -106,8 +106,8 @@ sub _child {
     try {
         my $result = $sub->();
         $self->_send_result( $pipe, $result, $pid );
-    } catch($err) {
-        $self->_send_error( $pipe, $err, $pid );
+    } catch {
+        $self->_send_error( $pipe, $_, $pid );
     };
 
     # Windows doesn't do fork(), it does threads...
@@ -311,7 +311,7 @@ Parallel::WorkUnit - Provide easy-to-use forking with ability to pass back data
 
 =head1 VERSION
 
-version 1.008
+version 1.009
 
 =head1 SYNOPSIS
 
